SetWeatherStation — pywws v12.11_95babb0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws v12.11_95babb0 documentation »
- Python programs and modules »

# SetWeatherStation

Set some weather station parameters.

usage: python SetWeatherStation.py [options] options are:

> `-h` | –help display this help
> `-c` | –clock set weather station clock to computer time (unlikely to work)

> -p f | –pressure f set relative pressure to n hPa -r n | –read_period n set logging interval to n minutes -v | –verbose increase error message verbosity -z | –zero_memory clear the weather station logged readings

Functions

`bcd_encode`(value) |
`main`([argv]) |

`SetWeatherStation.` `bcd_encode`(value)

`SetWeatherStation.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws v12.11_95babb0 documentation »
- Python programs and modules »